==> igniteui-react-charts-16.6.4.tgz: package/ES5/RadialBucketCalculator_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, Type, markType, runOn, EnumUtil, typeCast, fromEnum } from "igniteui-react-core/ES5/type";
import { IBucketizer_$type } from "./IBucketizer";
import { NotImplementedException } from "igniteui-react-core/ES5/NotImplementedException";
import { CategoryAngleAxis } from "./CategoryAngleAxis";
import { NumericRadiusAxis } from "./NumericRadiusAxis";
import { truncate } from "igniteui-react-core/ES5/number";
import { MarkerSeries } from "./MarkerSeries";
import { IHasCategoryModePreference_$type } from "./IHasCategoryModePreference";
import { SeriesRenderer$2 } from "./SeriesRenderer$2";
import { RadialFrame } from "./RadialFrame";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { SeriesPointOfInterest } from "./SeriesPointOfInterest";
import { ScalerParams } from "./ScalerParams";
import { Marker } from "./Marker";
import { MarkerSeriesView } from "./MarkerSeriesView";
import { RadialAxes } from "./RadialAxes";
import { Visibility_$type } from "igniteui-react-core/ES5/Visibility";
import { SeriesRenderingArguments } from "./SeriesRenderingArguments";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { Pool$1 } from "igniteui-react-core/ES5/Pool$1";
var RadialBucketCalculator = /** @class */ (function (_super) {
    tslib_1.__extends(RadialBucketCalculator, _super);
    function RadialBucketCalculator(a) {
        var _this = _super.call(this) || this;
        _this.a = null;
        _this.c = 0;
        _this.d = 0;
        _this.b = 0;
        _this.a = a;
        return _this;
    }
    RadialBucketCalculator.prototype.getBucket = function (a) {
        throw new NotImplementedException(0);
    };
    RadialBucketCalculator.prototype.getBucketWithoutUnknowns = function (a) {
        return this.getBucket(a);
    };
    RadialBucketCalculator.prototype.getErrorBucket = function (a, b) {
        return NaN;
    };
    RadialBucketCalculator.prototype.getBucketInfo = function (a, b, c, d) {
        a = this.c;
        b = this.d;
        c = this.b;
        d = this.a.cn.eq;
        return {
            p0: a,
            p1: b,
            p2: c,
            p3: d
        };
    };
    RadialBucketCalculator.prototype.e = function (a) {
        var b = this.a.bs;
        var c = this.a.br;
        var d = this.a.cn.mr;
        if (b.isEmpty || c.isEmpty || d == null || this.a.cn.bz == null || this.a.cn.bz.count == 0) {
            this.b = 0;
            return;
        }
        var e = Math.floor(d.k6(c, b));
        var f = Math.ceil(d.k5(c, b));
        if (d.b8) {
            f = Math.ceil(d.k6(c, b));
            e = Math.floor(d.k5(c, b));
        }
        if (f < e) {
            f = d.jr + f;
        }
        var g = this.a.cn.mt;
        var h = g != null ? g.lc : 0.75;
        var i = Math.min(c.width, c.height) * 0.5 * (h) * 2 * Math.PI;
        var j = Math.floor((f - e + 1) * a / i);
        this.b = truncate(Math.max(1, j));
        this.c = truncate(Math.max(0, Math.floor(e / this.b) - 1));
        this.d = truncate(Math.ceil(f / this.b));
    };
    RadialBucketCalculator.prototype.cacheValues = function () {
    };
    RadialBucketCalculator.prototype.unCacheValues = function () {
    };
    RadialBucketCalculator.$t = markType(RadialBucketCalculator, 'RadialBucketCalculator', Base.$, [IBucketizer_$type]);
    return RadialBucketCalculator;
}(Base));
export { RadialBucketCalculator };
var RadialBase = /** @class */ (function (_super) {
    tslib_1.__extends(RadialBase, _super);
    function RadialBase() {
        var _this = _super.call(this) || this;
        _this.mz = null;
        _this.mx = new RadialFrame(3);
        _this.my = new RadialFrame(3);
        _this.mw = new RadialFrame(3);
        _this.mu = null;
        _this.mz = new SeriesRenderer$2(RadialFrame.$, RadialBaseView.$, 1, runOn(_this, _this.nb), runOn(_this, _this.nc), runOn(_this, _this.ca), runOn(_this, _this.jc), runOn(_this, _this.na), function (a) { return _this.mv.co.e(_this.eq); });
        return _this;
    }
    RadialBase.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.mv = a;
    };
    RadialBase.prototype.na = function () {
        if (this.bt.g) {
            this.bt.t();
        }
    };
    Object.defineProperty(RadialBase.prototype, "categoryAxis", {
        get: function () {
            return this.mr;
        },
        enumerable: true,
        configurable: true
    });
    RadialBase.prototype.ap = function () {
        return this.mr;
    };
    RadialBase.prototype.m3 = function (a) {
        var _this = this;
        if (!this.hasMarkers) {
            return false;
        }
        var b = this.mr;
        var c = new ScalerParams(1, this.bs.mn, this.lp, b.b8);
        c.c = this.getEffectiveViewport1(this.bi);
        var d = this.mt;
        var e = new ScalerParams(1, this.bs.mn, this.lp, d.b8);
        e.c = this.getEffectiveViewport1(this.bi);
        a.clear();
        this.lr.cc(function (f) {
            if (f._visibility == 0) {
                var g = new SeriesPointOfInterest();
                var h = f.n;
                var i = f.o;
                if (h < _this.lp.left || h > _this.lp.right || i < _this.lp.top || i > _this.lp.bottom) {
                    return;
                }
                g.b = b.dw(h, c);
                g.c = d.dw(i, e);
                g.d = b.fe(f.ak);
                g.a = f.content;
                a.add(g);
            }
        });
        return true;
    };
    RadialBase.prototype.get_c2 = function () {
        return true;
    };
    RadialBase.prototype.ag = function () {
        return [this.mr, this.mt];
    };
    RadialBase.prototype.jk = function (a, b) {
        this.mv.co.e(this.eq);
        this.i4(false);
    };
    RadialBase.prototype.jj = function (a, b) {
        this.mv.co.e(this.eq);
        this.i4(false);
    };
    RadialBase.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case "SeriesViewer":
                if (c != null && d == null) {
                    if (this.mr != null) {
                        this.mr.bv(this);
                    }
                    if (this.mt != null) {
                        this.mt.bv(this);
                    }
                }
                if (c == null && d != null) {
                    if (this.mr != null) {
                        this.mr.ch(this);
                    }
                    if (this.mt != null) {
                        this.mt.ch(this);
                    }
                }
                this.mv.co.e(this.eq);
                this.i4(false);
                break;
            case RadialBase.$$p[0]:
                if (this.mr != null && this.mt != null) {
                    this.mu = new RadialAxes(this.mt, this.mr);
                }
                if (c != null) {
                    c.bv(this);
                }
                if (d != null) {
                    d.ch(this);
                }
                this.mv.co.e(this.eq);
                this.i4(false);
                break;
            case RadialBase.$$p[2]:
                if (this.mr != null && this.mt != null) {
                    this.mu = new RadialAxes(this.mt, this.mr);
                }
                if (c != null) {
                    c.bv(this);
                }
                if (d != null) {
                    d.ch(this);
                }
                this.mv.co.e(this.eq);
                if (this.mt == null || !this.mt.ck()) {
                    this.i4(false);
                }
                break;
            case "SyncLink":
                if (this.bn != null && this.bs != null) {
                    this.mv.co.e(this.eq);
                    this.i4(false);
                }
                break;
            case "TransitionProgress":
                this.my.c(this.ev, this.mx, this.mw);
                if (this.cc(this.bi)) {
                    return;
                }
                if (this.ev == 1) {
                    this.nc(this.mw, this.mv);
                }
                else {
                    this.nc(this.my, this.mv);
                }
                if (this.bs != null) {
                    this.bs.jh(this);
                }
                break;
            case RadialBase.$$p[1]:
                this.i4(false);
                this.ib();
                break;
            case "VisibilityProxy":
                if (EnumUtil.getEnumValue(Visibility_$type, c) != 0 && EnumUtil.getEnumValue(Visibility_$type, d) == 0) {
                    this.mv.co.e(this.eq);
                }
                break;
        }
    };
    RadialBase.prototype.m1 = function (a) {
        if (typeCast(NumericRadiusAxis.$, a) !== null) {
            return true;
        }
        return false;
    };
    RadialBase.prototype.m0 = function (a) {
        if (typeCast(CategoryAngleAxis.$, a) !== null) {
            return true;
        }
        return false;
    };
    RadialBase.prototype.fl = function (a) {
        var b = this.e4(a);
        return b >= 0 && this.bz != null && b < this.bz.count ? this.bz.item(b) : null;
    };
    RadialBase.prototype.m4 = function (a) {
        var b = this.bi.bs;
        var c = this.bi.br;
        if (this.mr != null && !b.isEmpty && !c.isEmpty && this.mu != null) {
            var d = this.mu.c(a);
            if (d < 0) {
                d += Math.PI * 2;
            }
            if (d > Math.PI * 2) {
                d -= Math.PI * 2;
            }
            return d;
        }
        return NaN;
    };
    RadialBase.prototype.m5 = function (a) {
        var b = this.bi.bs;
        var c = this.bi.br;
        var d = -1;
        if (this.mr != null && !b.isEmpty && !c.isEmpty && this.mu != null) {
            var e = this.mu.c(a);
            if (e < 0) {
                e += Math.PI * 2;
            }
            if (e > Math.PI * 2) {
                e -= Math.PI * 2;
            }
            var f = this.mr.getUnscaledAngle(e);
            if (this.mr.categoryMode != 0) {
                f -= 0.5;
            }
            d = f;
        }
        return d;
    };
    RadialBase.prototype.e4 = function (a) {
        var b = truncate(Math.round(this.m5(a)));
        if (this.bz != null && b == this.bz.count) {
            b = 0;
        }
        return b;
    };
    RadialBase.prototype.c7 = function (a) {
        return false;
    };
    RadialBase.prototype.h3 = function () {
        _super.prototype.h3.call(this);
        if (this.mr != null) {
            this.mr.g0(false);
        }
        if (this.mt != null) {
            this.mt.g0(false);
        }
    };
    RadialBase.prototype.du = function (a, b, c) {
        var d = true;
        var e = c;
        if (!_super.prototype.du.call(this, a, b, c) || !c.l() || b.isEmpty || a.isEmpty || this.mr == null || this.mr.itemsSource == null || this.mt == null || this.mu == null || this.bz == null || this.mr.bf == null || this.mt.bf == null || this.mt.jx == this.mt.jw) {
            e.co.b = 0;
            d = false;
        }
        return d;
    };
    RadialBase.prototype.i5 = function (a) {
        var b;
        var c;
        var d = this.getViewInfo(c, b);
        c = d.p0;
        b = d.p1;
        if (!this.du(c, b, this.bi)) {
            this.ho(true, this.bi);
            return;
        }
        var e = new SeriesRenderingArguments(this, c, b, a, this.dc);
        var f = this.mz.g(e, this.mx, this.mw, this.my, this.mv);
        this.mx = f.p1;
        this.mw = f.p2;
        this.my = f.p3;
    };
    RadialBase.prototype.m6 = function () {
        var e_1, _a;
        var a = 0;
        try {
            for (var _b = tslib_1.__values(fromEnum(this.bs.series)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var b = _c.value;
                if (b == this) {
                    return a;
                }
                var c = typeCast(RadialBase.$, b);
                if (c != null && c.mr == this.mr && c.preferredCategoryMode(c.mr) == 2) {
                    a++;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return -1;
    };
    RadialBase.$t = markType(RadialBase, 'RadialBase', MarkerSeries.$, [IHasCategoryModePreference_$type]);
    return RadialBase;
}(MarkerSeries));
export { RadialBase };
Type.dep(DependencyProperty, PropertyMetadata, RadialBase, 'raisePropertyChanged', ['AngleAxis:mr:nd', [CategoryAngleAxis.$, null], 'ClipSeriesToBounds:m2:ne', [0, false], 'ValueAxis:mt:nf', [NumericRadiusAxis.$, null]]);
var RadialBaseView = /** @class */ (function (_super) {
    tslib_1.__extends(RadialBaseView, _super);
    function RadialBaseView(a) {
        var _this = _super.call(this, a) || this;
        _this.co = null;
        _this.cn = null;
        _this.cp = null;
        _this.cq = 0;
        _this.cr = null;
        _this.cn = a;
        _this.cp = new Pool$1(Marker.$);
        _this.cf(_this.cp);
        return _this;
    }
    RadialBaseView.prototype.cc = function (a) {
        this.cp.c(a);
    };
    RadialBaseView.$t = markType(RadialBaseView, 'RadialBaseView', MarkerSeriesView.$);
    return RadialBaseView;
}(MarkerSeriesView));
export { RadialBaseView };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/RadialBucketCalculator_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, Type, markType, runOn, EnumUtil, typeCast, fromEnum } from "igniteui-react-core/ES5/type";
import { IBucketizer_$type } from "./IBucketizer";
import { NotImplementedException } from "igniteui-react-core/ES5/NotImplementedException";
import { CategoryAngleAxis } from "./CategoryAngleAxis";
import { NumericRadiusAxis } from "./NumericRadiusAxis";
import { truncate } from "igniteui-react-core/ES5/number";
import { MarkerSeries } from "./MarkerSeries";
import { IHasCategoryModePreference_$type } from "./IHasCategoryModePreference";
import { SeriesRenderer$2 } from "./SeriesRenderer$2";
import { RadialFrame } from "./RadialFrame";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { SeriesPointOfInterest } from "./SeriesPointOfInterest";
import { ScalerParams } from "./ScalerParams";
import { Marker } from "./Marker";
import { MarkerSeriesView } from "./MarkerSeriesView";
import { RadialAxes } from "./RadialAxes";
import { Visibility_$type } from "igniteui-react-core/ES5/Visibility";
import { SeriesRenderingArguments } from "./SeriesRenderingArguments";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { Pool$1 } from "igniteui-react-core/ES5/Pool$1";
/**
 * @hidden
 */
var RadialBucketCalculator = /** @class */ (function (_super) {
    tslib_1.__extends(RadialBucketCalculator, _super);
    function RadialBucketCalculator(a) {
        var _this = _super.call(this) || this;
        _this.a = null;
        _this.c = 0;
        _this.d = 0;
        _this.b = 0;
        _this.a = a;
        return _this;
    }
    RadialBucketCalculator.prototype.getBucket = function (a) {
        throw new NotImplementedException(0);
    };
    RadialBucketCalculator.prototype.getBucketWithoutUnknowns = function (a) {
        return this.getBucket(a);
    };
    RadialBucketCalculator.prototype.getErrorBucket = function (a, b) {
        return NaN;
    };
    RadialBucketCalculator.prototype.getBucketInfo = function (a, b, c, d) {
        a = this.c;
        b = this.d;
        c = this.b;
        d = this.a.cn.er;
        return {
            p0: a,
            p1: b,
            p2: c,
            p3: d
        };
    };
    RadialBucketCalculator.prototype.e = function (a) {
        var b = this.a.bs;
        var c = this.a.br;
        var d = this.a.cn.mt;
        if (b.isEmpty || c.isEmpty || d == null || this.a.cn.bz == null || this.a.cn.bz.count == 0) {
            this.b = 0;
            return;
        }
        var e = Math.floor(d.k6(c, b));
        var f = Math.ceil(d.k5(c, b));
        if (d.b8) {
            f = Math.ceil(d.k6(c, b));
            e = Math.floor(d.k5(c, b));
        }
        if (f < e) {
            f = d.jr + f;
        }
        var g = this.a.cn.mv;
        var h = g != null ? g.lc : 0.75;
        var i = Math.min(c.width, c.height) * 0.5 * (h) * 2 * Math.PI;
        var j = Math.floor((f - e + 1) * a / i);
        this.b = truncate(Math.max(1, j));
        this.c = truncate(Math.max(0, Math.floor(e / this.b) - 1));
        this.d = truncate(Math.ceil(f / this.b));
    };
    RadialBucketCalculator.prototype.cacheValues = function () {
    };
    RadialBucketCalculator.prototype.unCacheValues = function () {
    };
    RadialBucketCalculator.$t = markType(RadialBucketCalculator, 'RadialBucketCalculator', Base.$, [IBucketizer_$type]);
    return RadialBucketCalculator;
}(Base));
export { RadialBucketCalculator };
/**
 * @hidden
 */
var RadialBase = /** @class */ (function (_super) {
    tslib_1.__extends(RadialBase, _super);
    function RadialBase() {
        var _this = _super.call(this) || this;
        _this.m1 = null;
        _this.mz = new RadialFrame(3);
        _this.m0 = new RadialFrame(3);
        _this.my = new RadialFrame(3);
        _this.mw = null;
        _this.m1 = new SeriesRenderer$2(RadialFrame.$, RadialBaseView.$, 1, runOn(_this, _this.nd), runOn(_this, _this.ne), runOn(_this, _this.ca), runOn(_this, _this.je), runOn(_this, _this.nc), function (a) { return _this.mx.co.e(_this.er); });
        return _this;
    }
    RadialBase.prototype.im = function (a) {
        _super.prototype.im.call(this, a);
        this.mx = a;
    };
    RadialBase.prototype.nc = function () {
        if (this.bt.g) {
            this.bt.t();
        }
    };
    Object.defineProperty(RadialBase.prototype, "categoryAxis", {
        get: function () {
            return this.mt;
        },
        enumerable: true,
        configurable: true
    });
    RadialBase.prototype.ap = function () {
        return this.mt;
    };
    RadialBase.prototype.m5 = function (a) {
        var _this = this;
        if (!this.hasMarkers) {
            return false;
        }
        var b = this.mt;
        var c = new ScalerParams(1, this.bs.mq, this.lr, b.b8);
        c.c = this.getEffectiveViewport1(this.bi);
        var d = this.mv;
        var e = new ScalerParams(1, this.bs.mq, this.lr, d.b8);
        e.c = this.getEffectiveViewport1(this.bi);
        a.clear();
        this.lt.cc(function (f) {
            if (f._visibility == 0) {
                var g = new SeriesPointOfInterest();
                var h = f.n;
                var i = f.o;
                if (h < _this.lr.left || h > _this.lr.right || i < _this.lr.top || i > _this.lr.bottom) {
                    return;
                }
                g.b = b.dw(h, c);
                g.c = d.dw(i, e);
                g.d = b.fe(f.ak);
                g.a = f.content;
                a.add(g);
            }
        });
        return true;
    };
    RadialBase.prototype.get_c2 = function () {
        return true;
    };
    RadialBase.prototype.ag = function () {
        return [this.mt, this.mv];
    };
    RadialBase.prototype.jm = function (a, b) {
        this.mx.co.e(this.er);
        this.i6(false);
    };
    RadialBase.prototype.jl = function (a, b) {
        this.mx.co.e(this.er);
        this.i6(false);
    };
    RadialBase.prototype.is = function (a, b, c, d) {
        _super.prototype.is.call(this, a, b, c, d);
        switch (b) {
            case "SeriesViewer":
                if (c != null && d == null) {
                    if (this.mt != null) {
                        this.mt.bv(this);
                    }
                    if (this.mv != null) {
                        this.mv.bv(this);
                    }
                }
                if (c == null && d != null) {
                    if (this.mt != null) {
                        this.mt.ch(this);
                    }
                    if (this.mv != null) {
                        this.mv.ch(this);
                    }
                }
                this.mx.co.e(this.er);
                this.i6(false);
                break;
            case RadialBase.$$p[0]:
                if (this.mt != null && this.mv != null) {
                    this.mw = new RadialAxes(this.mv, this.mt);
                }
                if (c != null) {
                    c.bv(this);
                }
                if (d != null) {
                    d.ch(this);
                }
                this.mx.co.e(this.er);
                this.i6(false);
                break;
            case RadialBase.$$p[2]:
                if (this.mt != null && this.mv != null) {
                    this.mw = new RadialAxes(this.mv, this.mt);
                }
                if (c != null) {
                    c.bv(this);
                }
                if (d != null) {
                    d.ch(this);
                }
                this.mx.co.e(this.er);
                if (this.mv == null || !this.mv.ck()) {
                    this.i6(false);
                }
                break;
            case "SyncLink":
                if (this.bn != null && this.bs != null) {
                    this.mx.co.e(this.er);
                    this.i6(false);
                }
                break;
            case "TransitionProgress":
                this.m0.c(this.ew, this.mz, this.my);
                if (this.cc(this.bi)) {
                    return;
                }
                if (this.ew == 1) {
                    this.ne(this.my, this.mx);
                }
                else {
                    this.ne(this.m0, this.mx);
                }
                if (this.bs != null) {
                    this.bs.jj(this);
                }
                break;
            case RadialBase.$$p[1]:
                this.i6(false);
                this.ic();
                break;
            case "VisibilityProxy":
                if (EnumUtil.getEnumValue(Visibility_$type, c) != 0 && EnumUtil.getEnumValue(Visibility_$type, d) == 0) {
                    this.mx.co.e(this.er);
                }
                break;
        }
    };
    RadialBase.prototype.m3 = function (a) {
        if (typeCast(NumericRadiusAxis.$, a) !== null) {
            return true;
        }
        return false;
    };
    RadialBase.prototype.m2 = function (a) {
        if (typeCast(CategoryAngleAxis.$, a) !== null) {
            return true;
        }
        return false;
    };
    RadialBase.prototype.fm = function (a) {
        var b = this.e5(a);
        return b >= 0 && this.bz != null && b < this.bz.count ? this.bz.item(b) : null;
    };
    RadialBase.prototype.m6 = function (a) {
        var b = this.bi.bs;
        var c = this.bi.br;
        if (this.mt != null && !b.isEmpty && !c.isEmpty && this.mw != null) {
            var d = this.mw.c(a);
            if (d < 0) {
                d += Math.PI * 2;
            }
            if (d > Math.PI * 2) {
                d -= Math.PI * 2;
            }
            return d;
        }
        return NaN;
    };
    RadialBase.prototype.m7 = function (a) {
        var b = this.bi.bs;
        var c = this.bi.br;
        var d = -1;
        if (this.mt != null && !b.isEmpty && !c.isEmpty && this.mw != null) {
            var e = this.mw.c(a);
            if (e < 0) {
                e += Math.PI * 2;
            }
            if (e > Math.PI * 2) {
                e -= Math.PI * 2;
            }
            var f = this.mt.getUnscaledAngle(e);
            if (this.mt.categoryMode != 0) {
                f -= 0.5;
            }
            d = f;
        }
        return d;
    };
    RadialBase.prototype.e5 = function (a) {
        var b = truncate(Math.round(this.m7(a)));
        if (this.bz != null && b == this.bz.count) {
            b = 0;
        }
        return b;
    };
    RadialBase.prototype.c8 = function (a) {
        return false;
    };
    RadialBase.prototype.h4 = function () {
        _super.prototype.h4.call(this);
        if (this.mt != null) {
            this.mt.g0(false);
        }
        if (this.mv != null) {
            this.mv.g0(false);
        }
    };
    RadialBase.prototype.dv = function (a, b, c) {
        var d = true;
        var e = c;
        if (!_super.prototype.dv.call(this, a, b, c) || !c.l() || b.isEmpty || a.isEmpty || this.mt == null || this.mt.itemsSource == null || this.mv == null || this.mw == null || this.bz == null || this.mt.bf == null || this.mv.bf == null || this.mv.jx == this.mv.jw) {
            e.co.b = 0;
            d = false;
        }
        return d;
    };
    RadialBase.prototype.i7 = function (a) {
        var b;
        var c;
        var d = this.getViewInfo(c, b);
        c = d.p0;
        b = d.p1;
        if (!this.dv(c, b, this.bi)) {
            this.hp(true, this.bi);
            return;
        }
        var e = new SeriesRenderingArguments(this, c, b, a, this.dd);
        var f = this.m1.g(e, this.mz, this.my, this.m0, this.mx);
        this.mz = f.p1;
        this.my = f.p2;
        this.m0 = f.p3;
    };
    RadialBase.prototype.m8 = function () {
        var e_1, _a;
        var a = 0;
        try {
            for (var _b = tslib_1.__values(fromEnum(this.bs.series)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var b = _c.value;
                if (b == this) {
                    return a;
                }
                var c = typeCast(RadialBase.$, b);
                if (c != null && c.mt == this.mt && c.preferredCategoryMode(c.mt) == 2) {
                    a++;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return -1;
    };
    RadialBase.$t = markType(RadialBase, 'RadialBase', MarkerSeries.$, [IHasCategoryModePreference_$type]);
    return RadialBase;
}(MarkerSeries));
export { RadialBase };
Type.dep(DependencyProperty, PropertyMetadata, RadialBase, 'raisePropertyChanged', ['AngleAxis:mt:nf', [CategoryAngleAxis.$, null], 'ClipSeriesToBounds:m4:ng', [0, false], 'ValueAxis:mv:nh', [NumericRadiusAxis.$, null]]);
/**
 * @hidden
 */
var RadialBaseView = /** @class */ (function (_super) {
    tslib_1.__extends(RadialBaseView, _super);
    function RadialBaseView(a) {
        var _this = _super.call(this, a) || this;
        _this.co = null;
        _this.cn = null;
        _this.cp = null;
        _this.cq = 0;
        _this.cr = null;
        _this.cn = a;
        _this.cp = new Pool$1(Marker.$);
        _this.cf(_this.cp);
        return _this;
    }
    RadialBaseView.prototype.cc = function (a) {
        this.cp.c(a);
    };
    RadialBaseView.$t = markType(RadialBaseView, 'RadialBaseView', MarkerSeriesView.$);
    return RadialBaseView;
}(MarkerSeriesView));
export { RadialBaseView };
